Welcome to ttlru_map's documentation!
====================================
**ttlru_map** is a Python library which provides a hash table with a time-to-live (TTL) for each key-value pair.




.. toctree::
   :maxdepth: 2
   :caption: Contents:

Look at the :doc:`description` section for a more detailed description of the project.
Check out the :doc:`usage` section for further information, including how to
:ref:`install <installation>` the project.


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`


Contents
--------

.. toctree::

    description
    usage
    api
